import React, { Component, Fragment } from 'react';
import PropTypes from 'prop-types';
import { FormattedMessage } from 'react-intl';
import Popover from 'reactstrap/lib/Popover';
import PopoverBody from 'reactstrap/lib/PopoverBody';

import { IconServices } from '../icons/icon-services/icon-services';
import './services-menu.scss';

const SERVICES_MENU_ID = 'SERVICES_MENU_ID';

export class ServicesMenu extends Component {
  static propTypes = {
    serviceItems: PropTypes.arrayOf(PropTypes.shape({
      link: PropTypes.string.isRequired,
      message: PropTypes.string.isRequired,
      icon: PropTypes.node.isRequired,
    })).isRequired,
    hostname: PropTypes.string.isRequired,
  };

  state = {
    menuOpen: false,
  }

  toggleMenu = () => {
    this.setState(previousState => ({
      menuOpen: !previousState.menuOpen,
    }));
  }

  renderServiceItems = () => {
    const { serviceItems, hostname } = this.props;

    return serviceItems.map(({ link, message, icon }) => {
      const hrefProps = link.match(hostname)
        ? {
          href: '',
        }
        : {
          href: link,
          target: '_blank',
        };
      return (
        <a
          className="service-item py-2"
          key={`${link}${message}`}
          {...hrefProps}
        >
          {icon}
          <FormattedMessage id={message} />
        </a>
      );
    });
  }

  render() {
    const { menuOpen } = this.state;

    return (
      <Fragment>
        <IconServices
          toggleMenu={this.toggleMenu}
          id={SERVICES_MENU_ID}
        />
        <Popover
          placement="bottom-end"
          hideArrow
          isOpen={menuOpen}
          target={SERVICES_MENU_ID}
          toggle={this.toggleMenu}
          className="popover-services-menu"
        >
          <PopoverBody>
            <div className="services d-flex flex-wrap">
              {this.renderServiceItems()}
            </div>
          </PopoverBody>
        </Popover>
      </Fragment>
    );
  }
}
